# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'hardware_tests.ui',
# licensing of 'hardware_tests.ui' applies.
#
# Created: Tue Apr  2 19:21:47 2019
#      by: pyside2-uic  running on PySide2 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_HardwareTestDialog(object):
    def setupUi(self, HardwareTestDialog):
        HardwareTestDialog.setObjectName("HardwareTestDialog")
        HardwareTestDialog.resize(754, 426)
        self.verticalLayout = QtWidgets.QVBoxLayout(HardwareTestDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.testOutput = QtWidgets.QPlainTextEdit(HardwareTestDialog)
        self.testOutput.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.testOutput.setReadOnly(True)
        self.testOutput.setObjectName("testOutput")
        self.verticalLayout.addWidget(self.testOutput)
        self.buttonBox = QtWidgets.QDialogButtonBox(HardwareTestDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Close|QtWidgets.QDialogButtonBox.Reset)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(HardwareTestDialog)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("accepted()"), HardwareTestDialog.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("rejected()"), HardwareTestDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(HardwareTestDialog)

    def retranslateUi(self, HardwareTestDialog):
        HardwareTestDialog.setWindowTitle(QtWidgets.QApplication.translate("HardwareTestDialog", "Hardware Tests", None, -1))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ctrl_var_panel.ui',
# licensing of 'ctrl_var_panel.ui' applies.
#
# Created: Sun Mar 31 19:42:15 2019
#      by: pyside2-uic  running on PySide2 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_CtrlVarPanel(object):
    def setupUi(self, CtrlVarPanel):
        CtrlVarPanel.setObjectName("CtrlVarPanel")
        CtrlVarPanel.resize(99, 41)
        self.verticalLayout = QtWidgets.QVBoxLayout(CtrlVarPanel)
        self.verticalLayout.setObjectName("verticalLayout")
        self.ctrlVarLayout = QtWidgets.QVBoxLayout()
        self.ctrlVarLayout.setObjectName("ctrlVarLayout")
        self.verticalLayout.addLayout(self.ctrlVarLayout)
        spacerItem = QtWidgets.QSpacerItem(10, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem)

        self.retranslateUi(CtrlVarPanel)
        QtCore.QMetaObject.connectSlotsByName(CtrlVarPanel)

    def retranslateUi(self, CtrlVarPanel):
        CtrlVarPanel.setWindowTitle(QtWidgets.QApplication.translate("CtrlVarPanel", "Control Variable Panel", None, -1))
        CtrlVarPanel.setTitle(QtWidgets.QApplication.translate("CtrlVarPanel", "Control Variables", None, -1))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'bulk_update_firmware.ui',
# licensing of 'bulk_update_firmware.ui' applies.
#
# Created: Fri Oct 25 09:11:18 2019
#      by: pyside2-uic  running on PySide2 5.13.1
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_BulkUpdateFirmwareDialog(object):
    def setupUi(self, BulkUpdateFirmwareDialog):
        BulkUpdateFirmwareDialog.setObjectName("BulkUpdateFirmwareDialog")
        BulkUpdateFirmwareDialog.resize(387, 262)
        self.gridLayout = QtWidgets.QGridLayout(BulkUpdateFirmwareDialog)
        self.gridLayout.setObjectName("gridLayout")
        self.firmwareLabel = QtWidgets.QLabel(BulkUpdateFirmwareDialog)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.firmwareLabel.setFont(font)
        self.firmwareLabel.setObjectName("firmwareLabel")
        self.gridLayout.addWidget(self.firmwareLabel, 0, 0, 1, 4)
        spacerItem = QtWidgets.QSpacerItem(20, 13, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem, 1, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.firmwareLocation = QtWidgets.QLineEdit(BulkUpdateFirmwareDialog)
        self.firmwareLocation.setObjectName("firmwareLocation")
        self.horizontalLayout.addWidget(self.firmwareLocation)
        self.browseButton = QtWidgets.QPushButton(BulkUpdateFirmwareDialog)
        self.browseButton.setObjectName("browseButton")
        self.horizontalLayout.addWidget(self.browseButton)
        self.gridLayout.addLayout(self.horizontalLayout, 1, 1, 1, 3)
        self.serialRangeLabel = QtWidgets.QLabel(BulkUpdateFirmwareDialog)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.serialRangeLabel.setFont(font)
        self.serialRangeLabel.setObjectName("serialRangeLabel")
        self.gridLayout.addWidget(self.serialRangeLabel, 2, 0, 1, 4)
        self.minSerialLabel = QtWidgets.QLabel(BulkUpdateFirmwareDialog)
        self.minSerialLabel.setObjectName("minSerialLabel")
        self.gridLayout.addWidget(self.minSerialLabel, 3, 1, 1, 2)
        self.minSerial = QtWidgets.QSpinBox(BulkUpdateFirmwareDialog)
        self.minSerial.setMaximum(2147483647)
        self.minSerial.setObjectName("minSerial")
        self.gridLayout.addWidget(self.minSerial, 3, 3, 1, 1)
        self.maxSerialLabel = QtWidgets.QLabel(BulkUpdateFirmwareDialog)
        self.maxSerialLabel.setObjectName("maxSerialLabel")
        self.gridLayout.addWidget(self.maxSerialLabel, 4, 1, 1, 2)
        self.maxSerial = QtWidgets.QSpinBox(BulkUpdateFirmwareDialog)
        self.maxSerial.setMaximum(2147483647)
        self.maxSerial.setProperty("value", 2147483647)
        self.maxSerial.setObjectName("maxSerial")
        self.gridLayout.addWidget(self.maxSerial, 4, 3, 1, 1)
        self.setDeviceModeLabel = QtWidgets.QLabel(BulkUpdateFirmwareDialog)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.setDeviceModeLabel.setFont(font)
        self.setDeviceModeLabel.setObjectName("setDeviceModeLabel")
        self.gridLayout.addWidget(self.setDeviceModeLabel, 6, 0, 1, 4)
        self.setDeviceMode = QtWidgets.QCheckBox(BulkUpdateFirmwareDialog)
        self.setDeviceMode.setObjectName("setDeviceMode")
        self.gridLayout.addWidget(self.setDeviceMode, 7, 1, 1, 3)
        spacerItem1 = QtWidgets.QSpacerItem(20, 13, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem1, 8, 1, 1, 1)
        self.deviceModeLabel = QtWidgets.QLabel(BulkUpdateFirmwareDialog)
        self.deviceModeLabel.setEnabled(False)
        self.deviceModeLabel.setObjectName("deviceModeLabel")
        self.gridLayout.addWidget(self.deviceModeLabel, 8, 2, 1, 1)
        self.deviceMode = QtWidgets.QSpinBox(BulkUpdateFirmwareDialog)
        self.deviceMode.setEnabled(False)
        self.deviceMode.setMaximum(255)
        self.deviceMode.setProperty("value", 2)
        self.deviceMode.setObjectName("deviceMode")
        self.gridLayout.addWidget(self.deviceMode, 8, 3, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(369, 2, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem2, 9, 0, 1, 4)
        self.buttonBox = QtWidgets.QDialogButtonBox(BulkUpdateFirmwareDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 10, 0, 1, 4)
        self.radioStrengthLabel = QtWidgets.QLabel(BulkUpdateFirmwareDialog)
        self.radioStrengthLabel.setObjectName("radioStrengthLabel")
        self.gridLayout.addWidget(self.radioStrengthLabel, 5, 1, 1, 2)
        self.radioStrength = QtWidgets.QSpinBox(BulkUpdateFirmwareDialog)
        self.radioStrength.setMinimum(-100)
        self.radioStrength.setMaximum(0)
        self.radioStrength.setProperty("value", -100)
        self.radioStrength.setObjectName("radioStrength")
        self.gridLayout.addWidget(self.radioStrength, 5, 3, 1, 1)
        self.gridLayout.setColumnStretch(2, 1)

        self.retranslateUi(BulkUpdateFirmwareDialog)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("accepted()"), BulkUpdateFirmwareDialog.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("rejected()"), BulkUpdateFirmwareDialog.reject)
        QtCore.QObject.connect(self.setDeviceMode, QtCore.SIGNAL("toggled(bool)"), self.deviceModeLabel.setEnabled)
        QtCore.QObject.connect(self.setDeviceMode, QtCore.SIGNAL("toggled(bool)"), self.deviceMode.setEnabled)
        QtCore.QMetaObject.connectSlotsByName(BulkUpdateFirmwareDialog)
        BulkUpdateFirmwareDialog.setTabOrder(self.firmwareLocation, self.browseButton)
        BulkUpdateFirmwareDialog.setTabOrder(self.browseButton, self.minSerial)
        BulkUpdateFirmwareDialog.setTabOrder(self.minSerial, self.maxSerial)
        BulkUpdateFirmwareDialog.setTabOrder(self.maxSerial, self.setDeviceMode)
        BulkUpdateFirmwareDialog.setTabOrder(self.setDeviceMode, self.deviceMode)
        BulkUpdateFirmwareDialog.setTabOrder(self.deviceMode, self.buttonBox)

    def retranslateUi(self, BulkUpdateFirmwareDialog):
        BulkUpdateFirmwareDialog.setWindowTitle(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Bulk Update Firmware", None, -1))
        self.firmwareLabel.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Firmware", None, -1))
        self.browseButton.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Browse...", None, -1))
        self.serialRangeLabel.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Device Filtering", None, -1))
        self.minSerialLabel.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Minimum SN", None, -1))
        self.maxSerialLabel.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Maximum SN", None, -1))
        self.setDeviceModeLabel.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Set Device Mode", None, -1))
        self.setDeviceMode.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Set Device Mode After Update", None, -1))
        self.deviceModeLabel.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Device Mode", None, -1))
        self.radioStrengthLabel.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Minimum Radio Strength", None, -1))
        self.radioStrength.setSuffix(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", " dBm", None, -1))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'radio_panel.ui',
# licensing of 'radio_panel.ui' applies.
#
# Created: Fri Oct 25 09:11:21 2019
#      by: pyside2-uic  running on PySide2 5.13.1
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_RadioPanel(object):
    def setupUi(self, RadioPanel):
        RadioPanel.setObjectName("RadioPanel")
        RadioPanel.resize(115, 445)
        self.verticalLayout = QtWidgets.QVBoxLayout(RadioPanel)
        self.verticalLayout.setObjectName("verticalLayout")
        self.detailScanButton = QtWidgets.QPushButton(RadioPanel)
        self.detailScanButton.setObjectName("detailScanButton")
        self.verticalLayout.addWidget(self.detailScanButton)
        self.devicesComboBox = QtWidgets.QComboBox(RadioPanel)
        self.devicesComboBox.setObjectName("devicesComboBox")
        self.verticalLayout.addWidget(self.devicesComboBox)
        self.scanButton = QtWidgets.QPushButton(RadioPanel)
        self.scanButton.setObjectName("scanButton")
        self.verticalLayout.addWidget(self.scanButton)
        self.connectButton = QtWidgets.QPushButton(RadioPanel)
        self.connectButton.setObjectName("connectButton")
        self.verticalLayout.addWidget(self.connectButton)
        self.disconnectButton = QtWidgets.QPushButton(RadioPanel)
        self.disconnectButton.setObjectName("disconnectButton")
        self.verticalLayout.addWidget(self.disconnectButton)
        self.advancedMenuButton = QtWidgets.QPushButton(RadioPanel)
        self.advancedMenuButton.setObjectName("advancedMenuButton")
        self.verticalLayout.addWidget(self.advancedMenuButton)
        self.ctrlVarLayout = QtWidgets.QVBoxLayout()
        self.ctrlVarLayout.setObjectName("ctrlVarLayout")
        self.verticalLayout.addLayout(self.ctrlVarLayout)
        spacerItem = QtWidgets.QSpacerItem(10, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem)
        self.goToRemoteButton = QtWidgets.QPushButton(RadioPanel)
        self.goToRemoteButton.setObjectName("goToRemoteButton")
        self.verticalLayout.addWidget(self.goToRemoteButton)
        self.actionConnectAnyBootloader = QtWidgets.QAction(RadioPanel)
        self.actionConnectAnyBootloader.setObjectName("actionConnectAnyBootloader")
        self.actionConnectSpecificBootloader = QtWidgets.QAction(RadioPanel)
        self.actionConnectSpecificBootloader.setObjectName("actionConnectSpecificBootloader")
        self.actionBootloaderScan = QtWidgets.QAction(RadioPanel)
        self.actionBootloaderScan.setObjectName("actionBootloaderScan")
        self.actionConnectNoStreaming = QtWidgets.QAction(RadioPanel)
        self.actionConnectNoStreaming.setObjectName("actionConnectNoStreaming")
        self.actionBulkClaim = QtWidgets.QAction(RadioPanel)
        self.actionBulkClaim.setObjectName("actionBulkClaim")
        self.actionBulkUpdateFirmware = QtWidgets.QAction(RadioPanel)
        self.actionBulkUpdateFirmware.setObjectName("actionBulkUpdateFirmware")

        self.retranslateUi(RadioPanel)
        QtCore.QMetaObject.connectSlotsByName(RadioPanel)

    def retranslateUi(self, RadioPanel):
        RadioPanel.setWindowTitle(QtWidgets.QApplication.translate("RadioPanel", "Radio Panel", None, -1))
        RadioPanel.setTitle(QtWidgets.QApplication.translate("RadioPanel", "Radio", None, -1))
        self.detailScanButton.setText(QtWidgets.QApplication.translate("RadioPanel", "Detail Scan...", None, -1))
        self.scanButton.setText(QtWidgets.QApplication.translate("RadioPanel", "Quick Scan", None, -1))
        self.connectButton.setText(QtWidgets.QApplication.translate("RadioPanel", "Connect", None, -1))
        self.disconnectButton.setText(QtWidgets.QApplication.translate("RadioPanel", "Disconnect", None, -1))
        self.advancedMenuButton.setText(QtWidgets.QApplication.translate("RadioPanel", "Advanced Menu", None, -1))
        self.goToRemoteButton.setText(QtWidgets.QApplication.translate("RadioPanel", "Go To Remote Tab", None, -1))
        self.actionConnectAnyBootloader.setText(QtWidgets.QApplication.translate("RadioPanel", "Connect Any Bootloader", None, -1))
        self.actionConnectSpecificBootloader.setText(QtWidgets.QApplication.translate("RadioPanel", "Connect Specific Bootloader", None, -1))
        self.actionBootloaderScan.setText(QtWidgets.QApplication.translate("RadioPanel", "Bootloader Scan", None, -1))
        self.actionConnectNoStreaming.setText(QtWidgets.QApplication.translate("RadioPanel", "Connect (No Streaming)", None, -1))
        self.actionBulkClaim.setText(QtWidgets.QApplication.translate("RadioPanel", "Bulk Claim", None, -1))
        self.actionBulkClaim.setToolTip(QtWidgets.QApplication.translate("RadioPanel", "Bulk Claim", None, -1))
        self.actionBulkUpdateFirmware.setText(QtWidgets.QApplication.translate("RadioPanel", "Bulk Update Firmware", None, -1))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'radio_scan_dialog.ui',
# licensing of 'radio_scan_dialog.ui' applies.
#
# Created: Fri Apr 19 13:54:54 2019
#      by: pyside2-uic  running on PySide2 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_RadioScanDialog(object):
    def setupUi(self, RadioScanDialog):
        RadioScanDialog.setObjectName("RadioScanDialog")
        RadioScanDialog.resize(1000, 445)
        self.verticalLayout = QtWidgets.QVBoxLayout(RadioScanDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tableView = QtWidgets.QTableView(RadioScanDialog)
        self.tableView.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.tableView.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tableView.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.tableView.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tableView.setHorizontalScrollMode(QtWidgets.QAbstractItemView.ScrollPerPixel)
        self.tableView.setSortingEnabled(True)
        self.tableView.setCornerButtonEnabled(False)
        self.tableView.setObjectName("tableView")
        self.tableView.horizontalHeader().setStretchLastSection(True)
        self.tableView.verticalHeader().setVisible(False)
        self.verticalLayout.addWidget(self.tableView)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.activeScan = QtWidgets.QCheckBox(RadioScanDialog)
        self.activeScan.setObjectName("activeScan")
        self.horizontalLayout.addWidget(self.activeScan)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.filterLabel = QtWidgets.QLabel(RadioScanDialog)
        self.filterLabel.setObjectName("filterLabel")
        self.horizontalLayout.addWidget(self.filterLabel)
        self.filterSlider = QtWidgets.QSlider(RadioScanDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.filterSlider.sizePolicy().hasHeightForWidth())
        self.filterSlider.setSizePolicy(sizePolicy)
        self.filterSlider.setMinimumSize(QtCore.QSize(200, 0))
        self.filterSlider.setMinimum(-100)
        self.filterSlider.setMaximum(0)
        self.filterSlider.setOrientation(QtCore.Qt.Horizontal)
        self.filterSlider.setObjectName("filterSlider")
        self.horizontalLayout.addWidget(self.filterSlider)
        self.filterSpinBox = QtWidgets.QSpinBox(RadioScanDialog)
        self.filterSpinBox.setMinimum(-100)
        self.filterSpinBox.setMaximum(0)
        self.filterSpinBox.setObjectName("filterSpinBox")
        self.horizontalLayout.addWidget(self.filterSpinBox)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.buttonBox = QtWidgets.QDialogButtonBox(RadioScanDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok|QtWidgets.QDialogButtonBox.Reset)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(RadioScanDialog)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("accepted()"), RadioScanDialog.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("rejected()"), RadioScanDialog.reject)
        QtCore.QObject.connect(self.filterSlider, QtCore.SIGNAL("valueChanged(int)"), self.filterSpinBox.setValue)
        QtCore.QObject.connect(self.filterSpinBox, QtCore.SIGNAL("valueChanged(int)"), self.filterSlider.setValue)
        QtCore.QMetaObject.connectSlotsByName(RadioScanDialog)

    def retranslateUi(self, RadioScanDialog):
        RadioScanDialog.setWindowTitle(QtWidgets.QApplication.translate("RadioScanDialog", "Radio Scan", None, -1))
        self.activeScan.setText(QtWidgets.QApplication.translate("RadioScanDialog", "Active Scan", None, -1))
        self.filterLabel.setText(QtWidgets.QApplication.translate("RadioScanDialog", "Filter", None, -1))
        self.filterSpinBox.setSuffix(QtWidgets.QApplication.translate("RadioScanDialog", " dBm", None, -1))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tcp_connect_dialog.ui',
# licensing of 'tcp_connect_dialog.ui' applies.
#
# Created: Fri Oct 25 09:11:22 2019
#      by: pyside2-uic  running on PySide2 5.13.1
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_TCPConnectDialog(object):
    def setupUi(self, TCPConnectDialog):
        TCPConnectDialog.setObjectName("TCPConnectDialog")
        TCPConnectDialog.resize(915, 445)
        self.verticalLayout = QtWidgets.QVBoxLayout(TCPConnectDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tableWidget = QtWidgets.QTableWidget(TCPConnectDialog)
        self.tableWidget.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.tableWidget.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tableWidget.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tableWidget.setHorizontalScrollMode(QtWidgets.QAbstractItemView.ScrollPerPixel)
        self.tableWidget.setObjectName("tableWidget")
        self.tableWidget.setColumnCount(8)
        self.tableWidget.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(6, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(7, item)
        self.tableWidget.horizontalHeader().setHighlightSections(False)
        self.tableWidget.horizontalHeader().setStretchLastSection(True)
        self.tableWidget.verticalHeader().setVisible(False)
        self.verticalLayout.addWidget(self.tableWidget)
        self.automaticRescan = QtWidgets.QCheckBox(TCPConnectDialog)
        self.automaticRescan.setObjectName("automaticRescan")
        self.verticalLayout.addWidget(self.automaticRescan)
        self.buttonBox = QtWidgets.QDialogButtonBox(TCPConnectDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok|QtWidgets.QDialogButtonBox.Reset)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(TCPConnectDialog)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("accepted()"), TCPConnectDialog.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("rejected()"), TCPConnectDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(TCPConnectDialog)

    def retranslateUi(self, TCPConnectDialog):
        TCPConnectDialog.setWindowTitle(QtWidgets.QApplication.translate("TCPConnectDialog", "TCP Devices", None, -1))
        self.tableWidget.horizontalHeaderItem(0).setText(QtWidgets.QApplication.translate("TCPConnectDialog", "Serial", None, -1))
        self.tableWidget.horizontalHeaderItem(1).setText(QtWidgets.QApplication.translate("TCPConnectDialog", "Tag 1", None, -1))
        self.tableWidget.horizontalHeaderItem(2).setText(QtWidgets.QApplication.translate("TCPConnectDialog", "Tag 2", None, -1))
        self.tableWidget.horizontalHeaderItem(3).setText(QtWidgets.QApplication.translate("TCPConnectDialog", "Board Info", None, -1))
        self.tableWidget.horizontalHeaderItem(4).setText(QtWidgets.QApplication.translate("TCPConnectDialog", "Build Info", None, -1))
        self.tableWidget.horizontalHeaderItem(5).setText(QtWidgets.QApplication.translate("TCPConnectDialog", "Build Date", None, -1))
        self.tableWidget.horizontalHeaderItem(6).setText(QtWidgets.QApplication.translate("TCPConnectDialog", "Bootloader", None, -1))
        self.tableWidget.horizontalHeaderItem(7).setText(QtWidgets.QApplication.translate("TCPConnectDialog", "Available", None, -1))
        self.automaticRescan.setText(QtWidgets.QApplication.translate("TCPConnectDialog", "Automatic Rescan", None, -1))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'calibration_channel.ui',
# licensing of 'calibration_channel.ui' applies.
#
# Created: Tue Mar  3 13:57:37 2020
#      by: pyside2-uic  running on PySide2 5.13.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_CalibrationChannel(object):
    def setupUi(self, CalibrationChannel):
        CalibrationChannel.setObjectName("CalibrationChannel")
        CalibrationChannel.resize(195, 254)
        self.verticalLayout = QtWidgets.QVBoxLayout(CalibrationChannel)
        self.verticalLayout.setObjectName("verticalLayout")
        self.calibrationEnabled = QtWidgets.QCheckBox(CalibrationChannel)
        self.calibrationEnabled.setChecked(True)
        self.calibrationEnabled.setObjectName("calibrationEnabled")
        self.verticalLayout.addWidget(self.calibrationEnabled)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.unitLabel = QtWidgets.QLabel(CalibrationChannel)
        self.unitLabel.setObjectName("unitLabel")
        self.horizontalLayout_3.addWidget(self.unitLabel)
        self.unit = QtWidgets.QLabel(CalibrationChannel)
        self.unit.setObjectName("unit")
        self.horizontalLayout_3.addWidget(self.unit)
        spacerItem = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem)
        self.selectUnit = QtWidgets.QPushButton(CalibrationChannel)
        self.selectUnit.setObjectName("selectUnit")
        self.horizontalLayout_3.addWidget(self.selectUnit)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.acRadioButton = QtWidgets.QRadioButton(CalibrationChannel)
        self.acRadioButton.setChecked(True)
        self.acRadioButton.setObjectName("acRadioButton")
        self.horizontalLayout_2.addWidget(self.acRadioButton)
        self.linearRadioButton = QtWidgets.QRadioButton(CalibrationChannel)
        self.linearRadioButton.setObjectName("linearRadioButton")
        self.horizontalLayout_2.addWidget(self.linearRadioButton)
        spacerItem1 = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem1)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.stackedWidget = QtWidgets.QStackedWidget(CalibrationChannel)
        self.stackedWidget.setObjectName("stackedWidget")
        self.linearPage = QtWidgets.QWidget()
        self.linearPage.setObjectName("linearPage")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.linearPage)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.linearCapture = QtWidgets.QPushButton(self.linearPage)
        self.linearCapture.setObjectName("linearCapture")
        self.horizontalLayout_5.addWidget(self.linearCapture)
        spacerItem2 = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem2)
        self.plotButton = QtWidgets.QPushButton(self.linearPage)
        self.plotButton.setEnabled(False)
        self.plotButton.setObjectName("plotButton")
        self.horizontalLayout_5.addWidget(self.plotButton)
        self.verticalLayout_2.addLayout(self.horizontalLayout_5)
        self.linearTable = QtWidgets.QTableWidget(self.linearPage)
        self.linearTable.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.linearTable.setSelectionMode(QtWidgets.QAbstractItemView.NoSelection)
        self.linearTable.setHorizontalScrollMode(QtWidgets.QAbstractItemView.ScrollPerPixel)
        self.linearTable.setObjectName("linearTable")
        self.linearTable.setColumnCount(3)
        self.linearTable.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.linearTable.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.linearTable.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.linearTable.setHorizontalHeaderItem(2, item)
        self.verticalLayout_2.addWidget(self.linearTable)
        self.stackedWidget.addWidget(self.linearPage)
        self.acPage = QtWidgets.QWidget()
        self.acPage.setObjectName("acPage")
        self.formLayout = QtWidgets.QFormLayout(self.acPage)
        self.formLayout.setContentsMargins(0, 0, 0, 0)
        self.formLayout.setObjectName("formLayout")
        self.capturedMagnitudeLabel = QtWidgets.QLabel(self.acPage)
        self.capturedMagnitudeLabel.setObjectName("capturedMagnitudeLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.capturedMagnitudeLabel)
        self.capturedOffsetLabel = QtWidgets.QLabel(self.acPage)
        self.capturedOffsetLabel.setObjectName("capturedOffsetLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.capturedOffsetLabel)
        self.actualMagnitudeLabel = QtWidgets.QLabel(self.acPage)
        self.actualMagnitudeLabel.setObjectName("actualMagnitudeLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.actualMagnitudeLabel)
        self.actualOffsetLabel = QtWidgets.QLabel(self.acPage)
        self.actualOffsetLabel.setObjectName("actualOffsetLabel")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.actualOffsetLabel)
        self.capturedMagnitude = UnitFormatterDoubleSpinBox(self.acPage)
        self.capturedMagnitude.setObjectName("capturedMagnitude")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.capturedMagnitude)
        self.actualMagnitude = UnitFormatterDoubleSpinBox(self.acPage)
        self.actualMagnitude.setObjectName("actualMagnitude")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.actualMagnitude)
        self.capturedOffset = UnitFormatterDoubleSpinBox(self.acPage)
        self.capturedOffset.setObjectName("capturedOffset")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.capturedOffset)
        self.actualOffset = UnitFormatterDoubleSpinBox(self.acPage)
        self.actualOffset.setObjectName("actualOffset")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.actualOffset)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.acCapture = QtWidgets.QPushButton(self.acPage)
        self.acCapture.setObjectName("acCapture")
        self.horizontalLayout_4.addWidget(self.acCapture)
        spacerItem3 = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem3)
        self.formLayout.setLayout(0, QtWidgets.QFormLayout.SpanningRole, self.horizontalLayout_4)
        self.stackedWidget.addWidget(self.acPage)
        self.verticalLayout.addWidget(self.stackedWidget)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSpacing(6)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.scaleLabel = QtWidgets.QLabel(CalibrationChannel)
        self.scaleLabel.setObjectName("scaleLabel")
        self.horizontalLayout.addWidget(self.scaleLabel)
        self.scale = QtWidgets.QLineEdit(CalibrationChannel)
        self.scale.setReadOnly(True)
        self.scale.setObjectName("scale")
        self.horizontalLayout.addWidget(self.scale)
        self.offsetLabel = QtWidgets.QLabel(CalibrationChannel)
        self.offsetLabel.setObjectName("offsetLabel")
        self.horizontalLayout.addWidget(self.offsetLabel)
        self.offset = QtWidgets.QLineEdit(CalibrationChannel)
        self.offset.setReadOnly(True)
        self.offset.setObjectName("offset")
        self.horizontalLayout.addWidget(self.offset)
        self.verticalLayout.addLayout(self.horizontalLayout)

        self.retranslateUi(CalibrationChannel)
        self.stackedWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(CalibrationChannel)
        CalibrationChannel.setTabOrder(self.calibrationEnabled, self.selectUnit)
        CalibrationChannel.setTabOrder(self.selectUnit, self.acRadioButton)
        CalibrationChannel.setTabOrder(self.acRadioButton, self.linearRadioButton)
        CalibrationChannel.setTabOrder(self.linearRadioButton, self.acCapture)
        CalibrationChannel.setTabOrder(self.acCapture, self.capturedMagnitude)
        CalibrationChannel.setTabOrder(self.capturedMagnitude, self.capturedOffset)
        CalibrationChannel.setTabOrder(self.capturedOffset, self.actualMagnitude)
        CalibrationChannel.setTabOrder(self.actualMagnitude, self.actualOffset)
        CalibrationChannel.setTabOrder(self.actualOffset, self.linearCapture)
        CalibrationChannel.setTabOrder(self.linearCapture, self.linearTable)
        CalibrationChannel.setTabOrder(self.linearTable, self.scale)
        CalibrationChannel.setTabOrder(self.scale, self.offset)

    def retranslateUi(self, CalibrationChannel):
        self.calibrationEnabled.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Calibrate channel", None, -1))
        self.unitLabel.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Unit:", None, -1))
        self.unit.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Unit", None, -1))
        self.selectUnit.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Select Unit", None, -1))
        self.acRadioButton.setText(QtWidgets.QApplication.translate("CalibrationChannel", "AC RMS", None, -1))
        self.linearRadioButton.setText(QtWidgets.QApplication.translate("CalibrationChannel", "1st Order Linear", None, -1))
        self.linearCapture.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Capture", None, -1))
        self.plotButton.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Plot", None, -1))
        self.linearTable.horizontalHeaderItem(0).setText(QtWidgets.QApplication.translate("CalibrationChannel", "Captured", None, -1))
        self.linearTable.horizontalHeaderItem(1).setText(QtWidgets.QApplication.translate("CalibrationChannel", "Actual", None, -1))
        self.linearTable.horizontalHeaderItem(2).setText(QtWidgets.QApplication.translate("CalibrationChannel", "Delete", None, -1))
        self.capturedMagnitudeLabel.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Captured RMS Magnitude", None, -1))
        self.capturedOffsetLabel.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Captured DC Offset", None, -1))
        self.actualMagnitudeLabel.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Actual RMS Magnitude", None, -1))
        self.actualOffsetLabel.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Actual DC Offset", None, -1))
        self.acCapture.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Capture", None, -1))
        self.scaleLabel.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Scale", None, -1))
        self.offsetLabel.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Offset", None, -1))

from hyperborea.unit_formatter_spinbox import UnitFormatterDoubleSpinBox



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'plotmain.ui',
# licensing of 'plotmain.ui' applies.
#
# Created: Fri Mar 27 12:36:09 2020
#      by: pyside2-uic  running on PySide2 5.13.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_PlotMainWindow(object):
    def setupUi(self, PlotMainWindow):
        PlotMainWindow.setObjectName("PlotMainWindow")
        PlotMainWindow.resize(1200, 800)
        self.centralwidget = QtWidgets.QWidget(PlotMainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setContentsMargins(2, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget.setObjectName("tabWidget")
        self.verticalLayout.addWidget(self.tabWidget)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setSpacing(6)
        self.horizontalLayout_2.setContentsMargins(3, -1, 3, 1)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.warningLabel = QtWidgets.QLabel(self.centralwidget)
        self.warningLabel.setStyleSheet("QLabel { color : red ; font-weight : bold ; font-size : 18px ; }")
        self.warningLabel.setObjectName("warningLabel")
        self.horizontalLayout_2.addWidget(self.warningLabel)
        self.uploadRateLabel = QtWidgets.QLabel(self.centralwidget)
        self.uploadRateLabel.setMinimumSize(QtCore.QSize(75, 25))
        self.uploadRateLabel.setObjectName("uploadRateLabel")
        self.horizontalLayout_2.addWidget(self.uploadRateLabel)
        self.uploadProgress = QtWidgets.QProgressBar(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uploadProgress.sizePolicy().hasHeightForWidth())
        self.uploadProgress.setSizePolicy(sizePolicy)
        self.uploadProgress.setMinimumSize(QtCore.QSize(175, 25))
        self.uploadProgress.setMaximum(5957928)
        self.uploadProgress.setProperty("value", 2359296)
        self.uploadProgress.setAlignment(QtCore.Qt.AlignCenter)
        self.uploadProgress.setObjectName("uploadProgress")
        self.horizontalLayout_2.addWidget(self.uploadProgress)
        self.uploadNameLabel = QtWidgets.QLabel(self.centralwidget)
        self.uploadNameLabel.setObjectName("uploadNameLabel")
        self.horizontalLayout_2.addWidget(self.uploadNameLabel)
        spacerItem = QtWidgets.QSpacerItem(0, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.datetimeLabel = QtWidgets.QLabel(self.centralwidget)
        self.datetimeLabel.setObjectName("datetimeLabel")
        self.horizontalLayout_2.addWidget(self.datetimeLabel)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        PlotMainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(PlotMainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1200, 21))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuStreaming = QtWidgets.QMenu(self.menubar)
        self.menuStreaming.setObjectName("menuStreaming")
        self.menuSettings = QtWidgets.QMenu(self.menubar)
        self.menuSettings.setObjectName("menuSettings")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        self.menuCheckForUpdates = QtWidgets.QMenu(self.menuHelp)
        self.menuCheckForUpdates.setObjectName("menuCheckForUpdates")
        self.menuDevices = QtWidgets.QMenu(self.menubar)
        self.menuDevices.setObjectName("menuDevices")
        self.menuTools = QtWidgets.QMenu(self.menubar)
        self.menuTools.setObjectName("menuTools")
        self.menuMarkForUpload = QtWidgets.QMenu(self.menuTools)
        self.menuMarkForUpload.setObjectName("menuMarkForUpload")
        PlotMainWindow.setMenuBar(self.menubar)
        self.toolBar = QtWidgets.QToolBar(PlotMainWindow)
        self.toolBar.setMovable(False)
        self.toolBar.setIconSize(QtCore.QSize(32, 32))
        self.toolBar.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.toolBar.setFloatable(False)
        self.toolBar.setObjectName("toolBar")
        PlotMainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.actionRescanUSB = QtWidgets.QAction(PlotMainWindow)
        self.actionRescanUSB.setObjectName("actionRescanUSB")
        self.actionExit = QtWidgets.QAction(PlotMainWindow)
        self.actionExit.setObjectName("actionExit")
        self.actionPreferences = QtWidgets.QAction(PlotMainWindow)
        self.actionPreferences.setObjectName("actionPreferences")
        self.actionAbout = QtWidgets.QAction(PlotMainWindow)
        self.actionAbout.setObjectName("actionAbout")
        self.actionDisableStreaming = QtWidgets.QAction(PlotMainWindow)
        self.actionDisableStreaming.setCheckable(True)
        self.actionDisableStreaming.setObjectName("actionDisableStreaming")
        self.actionDisableArchiving = QtWidgets.QAction(PlotMainWindow)
        self.actionDisableArchiving.setCheckable(True)
        self.actionDisableArchiving.setObjectName("actionDisableArchiving")
        self.actionFindTCPDevices = QtWidgets.QAction(PlotMainWindow)
        self.actionFindTCPDevices.setObjectName("actionFindTCPDevices")
        self.actionEnableRFPower = QtWidgets.QAction(PlotMainWindow)
        self.actionEnableRFPower.setObjectName("actionEnableRFPower")
        self.actionDisableRFPower = QtWidgets.QAction(PlotMainWindow)
        self.actionDisableRFPower.setObjectName("actionDisableRFPower")
        self.actionPause = QtWidgets.QAction(PlotMainWindow)
        self.actionPause.setCheckable(True)
        self.actionPause.setObjectName("actionPause")
        self.actionResume = QtWidgets.QAction(PlotMainWindow)
        self.actionResume.setCheckable(True)
        self.actionResume.setObjectName("actionResume")
        self.actionClosableTabs = QtWidgets.QAction(PlotMainWindow)
        self.actionClosableTabs.setCheckable(True)
        self.actionClosableTabs.setObjectName("actionClosableTabs")
        self.actionUpdateLatestStable = QtWidgets.QAction(PlotMainWindow)
        self.actionUpdateLatestStable.setObjectName("actionUpdateLatestStable")
        self.actionUpdateSpecificBranch = QtWidgets.QAction(PlotMainWindow)
        self.actionUpdateSpecificBranch.setObjectName("actionUpdateSpecificBranch")
        self.actionUpdateSpecificCommit = QtWidgets.QAction(PlotMainWindow)
        self.actionUpdateSpecificCommit.setObjectName("actionUpdateSpecificCommit")
        self.actionUpdateCurrentBranch = QtWidgets.QAction(PlotMainWindow)
        self.actionUpdateCurrentBranch.setObjectName("actionUpdateCurrentBranch")
        self.actionDownloadFirmware = QtWidgets.QAction(PlotMainWindow)
        self.actionDownloadFirmware.setObjectName("actionDownloadFirmware")
        self.actionMarkFiles = QtWidgets.QAction(PlotMainWindow)
        self.actionMarkFiles.setObjectName("actionMarkFiles")
        self.actionMarkDirectory = QtWidgets.QAction(PlotMainWindow)
        self.actionMarkDirectory.setObjectName("actionMarkDirectory")
        self.menuFile.addAction(self.actionExit)
        self.menuStreaming.addAction(self.actionDisableStreaming)
        self.menuStreaming.addAction(self.actionDisableArchiving)
        self.menuSettings.addAction(self.actionClosableTabs)
        self.menuSettings.addAction(self.actionPreferences)
        self.menuCheckForUpdates.addAction(self.actionUpdateLatestStable)
        self.menuCheckForUpdates.addAction(self.actionUpdateCurrentBranch)
        self.menuCheckForUpdates.addAction(self.actionUpdateSpecificBranch)
        self.menuCheckForUpdates.addAction(self.actionUpdateSpecificCommit)
        self.menuHelp.addAction(self.menuCheckForUpdates.menuAction())
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.actionAbout)
        self.menuDevices.addAction(self.actionRescanUSB)
        self.menuDevices.addAction(self.actionFindTCPDevices)
        self.menuMarkForUpload.addAction(self.actionMarkFiles)
        self.menuMarkForUpload.addAction(self.actionMarkDirectory)
        self.menuTools.addAction(self.actionDownloadFirmware)
        self.menuTools.addSeparator()
        self.menuTools.addAction(self.menuMarkForUpload.menuAction())
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuDevices.menuAction())
        self.menubar.addAction(self.menuStreaming.menuAction())
        self.menubar.addAction(self.menuSettings.menuAction())
        self.menubar.addAction(self.menuTools.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())
        self.toolBar.addAction(self.actionEnableRFPower)
        self.toolBar.addAction(self.actionDisableRFPower)
        self.toolBar.addAction(self.actionRescanUSB)
        self.toolBar.addAction(self.actionFindTCPDevices)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionPause)
        self.toolBar.addAction(self.actionResume)

        self.retranslateUi(PlotMainWindow)
        QtCore.QObject.connect(self.actionExit, QtCore.SIGNAL("triggered()"), PlotMainWindow.close)
        QtCore.QMetaObject.connectSlotsByName(PlotMainWindow)

    def retranslateUi(self, PlotMainWindow):
        PlotMainWindow.setWindowTitle(QtWidgets.QApplication.translate("PlotMainWindow", "Acheron", None, -1))
        self.warningLabel.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Warning: Archiving Disabled", None, -1))
        self.uploadRateLabel.setText(QtWidgets.QApplication.translate("PlotMainWindow", "350 kB/s", None, -1))
        self.uploadProgress.setFormat(QtWidgets.QApplication.translate("PlotMainWindow", "%v/%m (%p%)", None, -1))
        self.uploadNameLabel.setText(QtWidgets.QApplication.translate("PlotMainWindow", "20181029T2241Z_HSS2143.apd", None, -1))
        self.datetimeLabel.setText(QtWidgets.QApplication.translate("PlotMainWindow", "0000-00-00T00:00:00Z", None, -1))
        self.menuFile.setTitle(QtWidgets.QApplication.translate("PlotMainWindow", "File", None, -1))
        self.menuStreaming.setTitle(QtWidgets.QApplication.translate("PlotMainWindow", "Streaming", None, -1))
        self.menuSettings.setTitle(QtWidgets.QApplication.translate("PlotMainWindow", "Settings", None, -1))
        self.menuHelp.setTitle(QtWidgets.QApplication.translate("PlotMainWindow", "Help", None, -1))
        self.menuCheckForUpdates.setTitle(QtWidgets.QApplication.translate("PlotMainWindow", "Check for Updates", None, -1))
        self.menuDevices.setTitle(QtWidgets.QApplication.translate("PlotMainWindow", "Devices", None, -1))
        self.menuTools.setTitle(QtWidgets.QApplication.translate("PlotMainWindow", "Tools", None, -1))
        self.menuMarkForUpload.setTitle(QtWidgets.QApplication.translate("PlotMainWindow", "Mark for Upload", None, -1))
        self.actionRescanUSB.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Rescan USB", None, -1))
        self.actionExit.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Exit", None, -1))
        self.actionPreferences.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Preferences...", None, -1))
        self.actionAbout.setText(QtWidgets.QApplication.translate("PlotMainWindow", "About...", None, -1))
        self.actionDisableStreaming.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Disable Streaming", None, -1))
        self.actionDisableArchiving.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Disable Archiving", None, -1))
        self.actionFindTCPDevices.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Find TCP Devices...", None, -1))
        self.actionEnableRFPower.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Enable RF Power (0)", None, -1))
        self.actionDisableRFPower.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Disable RF Power (0)", None, -1))
        self.actionPause.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Pause", None, -1))
        self.actionResume.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Resume", None, -1))
        self.actionClosableTabs.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Easy Close Tabs", None, -1))
        self.actionClosableTabs.setToolTip(QtWidgets.QApplication.translate("PlotMainWindow", "Easy Close Tabs", None, -1))
        self.actionUpdateLatestStable.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Latest Stable", None, -1))
        self.actionUpdateSpecificBranch.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Specific Branch...", None, -1))
        self.actionUpdateSpecificCommit.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Specific Commit..", None, -1))
        self.actionUpdateCurrentBranch.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Latest branch", None, -1))
        self.actionDownloadFirmware.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Download Firmware...", None, -1))
        self.actionDownloadFirmware.setToolTip(QtWidgets.QApplication.translate("PlotMainWindow", "Download Firmware...", None, -1))
        self.actionMarkFiles.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Mark Files...", None, -1))
        self.actionMarkFiles.setToolTip(QtWidgets.QApplication.translate("PlotMainWindow", "Mark Files...", None, -1))
        self.actionMarkDirectory.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Mark Directory...", None, -1))
        self.actionMarkDirectory.setToolTip(QtWidgets.QApplication.translate("PlotMainWindow", "Mark Directory...", None, -1))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'about.ui',
# licensing of 'about.ui' applies.
#
# Created: Fri Mar 27 10:22:04 2020
#      by: pyside2-uic  running on PySide2 5.13.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_AboutDialog(object):
    def setupUi(self, AboutDialog):
        AboutDialog.setObjectName("AboutDialog")
        AboutDialog.resize(302, 232)
        self.verticalLayout = QtWidgets.QVBoxLayout(AboutDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.productLabel = QtWidgets.QLabel(AboutDialog)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.productLabel.setFont(font)
        self.productLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.productLabel.setObjectName("productLabel")
        self.verticalLayout.addWidget(self.productLabel)
        self.companyLabel = QtWidgets.QLabel(AboutDialog)
        self.companyLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.companyLabel.setOpenExternalLinks(True)
        self.companyLabel.setObjectName("companyLabel")
        self.verticalLayout.addWidget(self.companyLabel)
        self.copyrightLabel = QtWidgets.QLabel(AboutDialog)
        self.copyrightLabel.setTextFormat(QtCore.Qt.RichText)
        self.copyrightLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.copyrightLabel.setObjectName("copyrightLabel")
        self.verticalLayout.addWidget(self.copyrightLabel)
        spacerItem = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem)
        self.version = QtWidgets.QLabel(AboutDialog)
        self.version.setAlignment(QtCore.Qt.AlignCenter)
        self.version.setObjectName("version")
        self.verticalLayout.addWidget(self.version)
        self.buildDate = QtWidgets.QLabel(AboutDialog)
        self.buildDate.setAlignment(QtCore.Qt.AlignCenter)
        self.buildDate.setObjectName("buildDate")
        self.verticalLayout.addWidget(self.buildDate)
        spacerItem1 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem1)
        self.libraryVersionsLabel = QtWidgets.QLabel(AboutDialog)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.libraryVersionsLabel.setFont(font)
        self.libraryVersionsLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.libraryVersionsLabel.setObjectName("libraryVersionsLabel")
        self.verticalLayout.addWidget(self.libraryVersionsLabel)
        self.libraryVersions = QtWidgets.QLabel(AboutDialog)
        self.libraryVersions.setObjectName("libraryVersions")
        self.verticalLayout.addWidget(self.libraryVersions)
        spacerItem2 = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem2)
        self.buttonBox = QtWidgets.QDialogButtonBox(AboutDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Close)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(AboutDialog)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("accepted()"), AboutDialog.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("rejected()"), AboutDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(AboutDialog)

    def retranslateUi(self, AboutDialog):
        AboutDialog.setWindowTitle(QtWidgets.QApplication.translate("AboutDialog", "About Acheron", None, -1))
        self.productLabel.setText(QtWidgets.QApplication.translate("AboutDialog", "Acheron", None, -1))
        self.companyLabel.setText(QtWidgets.QApplication.translate("AboutDialog", "by <a href=\"http://suprocktech.com/\">Suprock Technologies</a>", None, -1))
        self.copyrightLabel.setText(QtWidgets.QApplication.translate("AboutDialog", "&copy; 2019", None, -1))
        self.version.setText(QtWidgets.QApplication.translate("AboutDialog", "Version", None, -1))
        self.buildDate.setText(QtWidgets.QApplication.translate("AboutDialog", "Build Date", None, -1))
        self.libraryVersionsLabel.setText(QtWidgets.QApplication.translate("AboutDialog", "Libraries", None, -1))
        self.libraryVersions.setText(QtWidgets.QApplication.translate("AboutDialog", "library: version", None, -1))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'preferences.ui',
# licensing of 'preferences.ui' applies.
#
# Created: Fri Mar 27 10:12:20 2020
#      by: pyside2-uic  running on PySide2 5.13.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_PreferencesDialog(object):
    def setupUi(self, PreferencesDialog):
        PreferencesDialog.setObjectName("PreferencesDialog")
        PreferencesDialog.resize(414, 379)
        self.verticalLayout = QtWidgets.QVBoxLayout(PreferencesDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tabWidget = QtWidgets.QTabWidget(PreferencesDialog)
        self.tabWidget.setObjectName("tabWidget")
        self.streamingTab = QtWidgets.QWidget()
        self.streamingTab.setObjectName("streamingTab")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.streamingTab)
        self.gridLayout_3.setObjectName("gridLayout_3")
        spacerItem = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem, 1, 0, 1, 1)
        self.automaticRGBCheckBox = QtWidgets.QCheckBox(self.streamingTab)
        self.automaticRGBCheckBox.setChecked(True)
        self.automaticRGBCheckBox.setObjectName("automaticRGBCheckBox")
        self.gridLayout_3.addWidget(self.automaticRGBCheckBox, 1, 1, 1, 1)
        self.ledsLabel = QtWidgets.QLabel(self.streamingTab)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.ledsLabel.setFont(font)
        self.ledsLabel.setObjectName("ledsLabel")
        self.gridLayout_3.addWidget(self.ledsLabel, 0, 0, 1, 2)
        spacerItem1 = QtWidgets.QSpacerItem(369, 243, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_3.addItem(spacerItem1, 5, 0, 1, 2)
        self.downsamplingLabel = QtWidgets.QLabel(self.streamingTab)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.downsamplingLabel.setFont(font)
        self.downsamplingLabel.setObjectName("downsamplingLabel")
        self.gridLayout_3.addWidget(self.downsamplingLabel, 2, 0, 1, 2)
        self.downsampleCheckBox = QtWidgets.QCheckBox(self.streamingTab)
        self.downsampleCheckBox.setChecked(True)
        self.downsampleCheckBox.setObjectName("downsampleCheckBox")
        self.gridLayout_3.addWidget(self.downsampleCheckBox, 3, 1, 1, 1)
        self.tabWidget.addTab(self.streamingTab, "")
        self.unitTab = QtWidgets.QWidget()
        self.unitTab.setObjectName("unitTab")
        self.gridLayout = QtWidgets.QGridLayout(self.unitTab)
        self.gridLayout.setObjectName("gridLayout")
        self.unitsLabel = QtWidgets.QLabel(self.unitTab)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.unitsLabel.setFont(font)
        self.unitsLabel.setObjectName("unitsLabel")
        self.gridLayout.addWidget(self.unitsLabel, 0, 0, 1, 2)
        spacerItem2 = QtWidgets.QSpacerItem(20, 13, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem2, 1, 0, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem3, 4, 0, 1, 2)
        self.unitPreferences = UnitPreferencesWidget(self.unitTab)
        self.unitPreferences.setObjectName("unitPreferences")
        self.gridLayout.addWidget(self.unitPreferences, 1, 1, 1, 1)
        self.tabWidget.addTab(self.unitTab, "")
        self.outputTab = QtWidgets.QWidget()
        self.outputTab.setObjectName("outputTab")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.outputTab)
        self.gridLayout_2.setObjectName("gridLayout_2")
        spacerItem4 = QtWidgets.QSpacerItem(369, 237, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem4, 6, 0, 1, 3)
        self.outputLocationLabel = QtWidgets.QLabel(self.outputTab)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.outputLocationLabel.setFont(font)
        self.outputLocationLabel.setObjectName("outputLocationLabel")
        self.gridLayout_2.addWidget(self.outputLocationLabel, 0, 0, 1, 3)
        self.compressionLevel = QtWidgets.QSpinBox(self.outputTab)
        self.compressionLevel.setMinimum(0)
        self.compressionLevel.setMaximum(9)
        self.compressionLevel.setProperty("value", 6)
        self.compressionLevel.setObjectName("compressionLevel")
        self.gridLayout_2.addWidget(self.compressionLevel, 5, 2, 1, 1)
        self.compressionLabel = QtWidgets.QLabel(self.outputTab)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.compressionLabel.setFont(font)
        self.compressionLabel.setObjectName("compressionLabel")
        self.gridLayout_2.addWidget(self.compressionLabel, 3, 0, 1, 3)
        self.compressionLevelLabel = QtWidgets.QLabel(self.outputTab)
        self.compressionLevelLabel.setObjectName("compressionLevelLabel")
        self.gridLayout_2.addWidget(self.compressionLevelLabel, 5, 1, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.outputLocation = QtWidgets.QLineEdit(self.outputTab)
        self.outputLocation.setObjectName("outputLocation")
        self.horizontalLayout.addWidget(self.outputLocation)
        self.browseButton = QtWidgets.QPushButton(self.outputTab)
        self.browseButton.setObjectName("browseButton")
        self.horizontalLayout.addWidget(self.browseButton)
        self.gridLayout_2.addLayout(self.horizontalLayout, 1, 1, 1, 2)
        spacerItem5 = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem5, 1, 0, 1, 1)
        self.gridLayout_2.setColumnStretch(1, 1)
        self.tabWidget.addTab(self.outputTab, "")
        self.uploadTab = QtWidgets.QWidget()
        self.uploadTab.setObjectName("uploadTab")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.uploadTab)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.uploadAccessKeyID = QtWidgets.QLineEdit(self.uploadTab)
        self.uploadAccessKeyID.setEnabled(False)
        self.uploadAccessKeyID.setObjectName("uploadAccessKeyID")
        self.gridLayout_4.addWidget(self.uploadAccessKeyID, 5, 3, 1, 1)
        self.uploadAccessKeyIDLabel = QtWidgets.QLabel(self.uploadTab)
        self.uploadAccessKeyIDLabel.setEnabled(False)
        self.uploadAccessKeyIDLabel.setObjectName("uploadAccessKeyIDLabel")
        self.gridLayout_4.addWidget(self.uploadAccessKeyIDLabel, 5, 2, 1, 1)
        spacerItem6 = QtWidgets.QSpacerItem(20, 13, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem6, 2, 1, 1, 1)
        self.enableUpload = QtWidgets.QCheckBox(self.uploadTab)
        self.enableUpload.setObjectName("enableUpload")
        self.gridLayout_4.addWidget(self.enableUpload, 1, 1, 1, 3)
        self.uploadSecretAccessKey = QtWidgets.QLineEdit(self.uploadTab)
        self.uploadSecretAccessKey.setEnabled(False)
        self.uploadSecretAccessKey.setEchoMode(QtWidgets.QLineEdit.PasswordEchoOnEdit)
        self.uploadSecretAccessKey.setObjectName("uploadSecretAccessKey")
        self.gridLayout_4.addWidget(self.uploadSecretAccessKey, 6, 3, 1, 1)
        self.s3BucketLabel = QtWidgets.QLabel(self.uploadTab)
        self.s3BucketLabel.setEnabled(False)
        self.s3BucketLabel.setObjectName("s3BucketLabel")
        self.gridLayout_4.addWidget(self.s3BucketLabel, 2, 2, 1, 1)
        self.uploadLabel = QtWidgets.QLabel(self.uploadTab)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.uploadLabel.setFont(font)
        self.uploadLabel.setObjectName("uploadLabel")
        self.gridLayout_4.addWidget(self.uploadLabel, 0, 0, 1, 3)
        self.uploadDirectoryLabel = QtWidgets.QLabel(self.uploadTab)
        self.uploadDirectoryLabel.setEnabled(False)
        self.uploadDirectoryLabel.setObjectName("uploadDirectoryLabel")
        self.gridLayout_4.addWidget(self.uploadDirectoryLabel, 4, 2, 1, 1)
        self.uploadDirectory = QtWidgets.QLineEdit(self.uploadTab)
        self.uploadDirectory.setEnabled(False)
        self.uploadDirectory.setObjectName("uploadDirectory")
        self.gridLayout_4.addWidget(self.uploadDirectory, 4, 3, 1, 1)
        spacerItem7 = QtWidgets.QSpacerItem(20, 13, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem7, 1, 0, 1, 1)
        spacerItem8 = QtWidgets.QSpacerItem(369, 116, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_4.addItem(spacerItem8, 8, 0, 1, 4)
        self.s3Bucket = QtWidgets.QLineEdit(self.uploadTab)
        self.s3Bucket.setEnabled(False)
        self.s3Bucket.setObjectName("s3Bucket")
        self.gridLayout_4.addWidget(self.s3Bucket, 2, 3, 1, 1)
        self.uploadDeleteOriginal = QtWidgets.QCheckBox(self.uploadTab)
        self.uploadDeleteOriginal.setEnabled(False)
        self.uploadDeleteOriginal.setObjectName("uploadDeleteOriginal")
        self.gridLayout_4.addWidget(self.uploadDeleteOriginal, 7, 2, 1, 2)
        self.uploadSecretAccessKeyLabel = QtWidgets.QLabel(self.uploadTab)
        self.uploadSecretAccessKeyLabel.setEnabled(False)
        self.uploadSecretAccessKeyLabel.setObjectName("uploadSecretAccessKeyLabel")
        self.gridLayout_4.addWidget(self.uploadSecretAccessKeyLabel, 6, 2, 1, 1)
        self.awsRegionLabel = QtWidgets.QLabel(self.uploadTab)
        self.awsRegionLabel.setEnabled(False)
        self.awsRegionLabel.setObjectName("awsRegionLabel")
        self.gridLayout_4.addWidget(self.awsRegionLabel, 3, 2, 1, 1)
        self.awsRegion = QtWidgets.QLineEdit(self.uploadTab)
        self.awsRegion.setEnabled(False)
        self.awsRegion.setObjectName("awsRegion")
        self.gridLayout_4.addWidget(self.awsRegion, 3, 3, 1, 1)
        self.tabWidget.addTab(self.uploadTab, "")
        self.verticalLayout.addWidget(self.tabWidget)
        self.buttonBox = QtWidgets.QDialogButtonBox(PreferencesDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(PreferencesDialog)
        self.tabWidget.setCurrentIndex(1)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("accepted()"), PreferencesDialog.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("rejected()"), PreferencesDialog.reject)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.s3BucketLabel.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.s3Bucket.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.uploadDirectoryLabel.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.uploadDirectory.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.uploadAccessKeyIDLabel.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.uploadAccessKeyID.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.uploadSecretAccessKeyLabel.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.uploadSecretAccessKey.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.uploadDeleteOriginal.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.awsRegionLabel.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.awsRegion.setEnabled)
        QtCore.QMetaObject.connectSlotsByName(PreferencesDialog)
        PreferencesDialog.setTabOrder(self.tabWidget, self.automaticRGBCheckBox)
        PreferencesDialog.setTabOrder(self.automaticRGBCheckBox, self.outputLocation)
        PreferencesDialog.setTabOrder(self.outputLocation, self.browseButton)
        PreferencesDialog.setTabOrder(self.browseButton, self.compressionLevel)
        PreferencesDialog.setTabOrder(self.compressionLevel, self.enableUpload)
        PreferencesDialog.setTabOrder(self.enableUpload, self.s3Bucket)
        PreferencesDialog.setTabOrder(self.s3Bucket, self.awsRegion)
        PreferencesDialog.setTabOrder(self.awsRegion, self.uploadDirectory)
        PreferencesDialog.setTabOrder(self.uploadDirectory, self.uploadAccessKeyID)
        PreferencesDialog.setTabOrder(self.uploadAccessKeyID, self.uploadSecretAccessKey)
        PreferencesDialog.setTabOrder(self.uploadSecretAccessKey, self.uploadDeleteOriginal)
        PreferencesDialog.setTabOrder(self.uploadDeleteOriginal, self.buttonBox)

    def retranslateUi(self, PreferencesDialog):
        PreferencesDialog.setWindowTitle(QtWidgets.QApplication.translate("PreferencesDialog", "Preferences", None, -1))
        self.automaticRGBCheckBox.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Automatically set RGB LEDs when connecting/disconnecting", None, -1))
        self.ledsLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "RGB LEDs", None, -1))
        self.downsamplingLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Downsampling", None, -1))
        self.downsampleCheckBox.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Downsample high speed channels (for time domain graph only)", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.streamingTab), QtWidgets.QApplication.translate("PreferencesDialog", "Streaming", None, -1))
        self.unitsLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Display Units", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.unitTab), QtWidgets.QApplication.translate("PreferencesDialog", "Units", None, -1))
        self.outputLocationLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Output Location", None, -1))
        self.compressionLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Compression", None, -1))
        self.compressionLevelLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Compression Level (default 6)", None, -1))
        self.browseButton.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Browse...", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.outputTab), QtWidgets.QApplication.translate("PreferencesDialog", "Output", None, -1))
        self.uploadAccessKeyIDLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "AWS Access Key ID", None, -1))
        self.enableUpload.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Enable AWS S3 Upload", None, -1))
        self.s3BucketLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "S3 Bucket", None, -1))
        self.uploadLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Amazon S3 Upload", None, -1))
        self.uploadDirectoryLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Upload Directory", None, -1))
        self.uploadDeleteOriginal.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Delete original .apd after successful upload", None, -1))
        self.uploadSecretAccessKeyLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "AWS Secret Access Key", None, -1))
        self.awsRegionLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "S3 Bucket AWS Region", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.uploadTab), QtWidgets.QApplication.translate("PreferencesDialog", "Cloud Upload", None, -1))

from hyperborea.unit_preferences import UnitPreferencesWidget



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'rgb_control_widget.ui',
# licensing of 'rgb_control_widget.ui' applies.
#
# Created: Sun Mar 31 19:42:18 2019
#      by: pyside2-uic  running on PySide2 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_RGBControlWidget(object):
    def setupUi(self, RGBControlWidget):
        RGBControlWidget.setObjectName("RGBControlWidget")
        RGBControlWidget.resize(239, 192)
        self.verticalLayout = QtWidgets.QVBoxLayout(RGBControlWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.whiteButton = QtWidgets.QPushButton(RGBControlWidget)
        self.whiteButton.setObjectName("whiteButton")
        self.gridLayout.addWidget(self.whiteButton, 0, 1, 1, 1)
        self.redButton = QtWidgets.QPushButton(RGBControlWidget)
        self.redButton.setObjectName("redButton")
        self.gridLayout.addWidget(self.redButton, 1, 0, 1, 1)
        self.greenButton = QtWidgets.QPushButton(RGBControlWidget)
        self.greenButton.setObjectName("greenButton")
        self.gridLayout.addWidget(self.greenButton, 1, 1, 1, 1)
        self.blueButton = QtWidgets.QPushButton(RGBControlWidget)
        self.blueButton.setObjectName("blueButton")
        self.gridLayout.addWidget(self.blueButton, 1, 2, 1, 1)
        self.cyanButton = QtWidgets.QPushButton(RGBControlWidget)
        self.cyanButton.setObjectName("cyanButton")
        self.gridLayout.addWidget(self.cyanButton, 2, 0, 1, 1)
        self.magentaButton = QtWidgets.QPushButton(RGBControlWidget)
        self.magentaButton.setObjectName("magentaButton")
        self.gridLayout.addWidget(self.magentaButton, 2, 1, 1, 1)
        self.yellowButton = QtWidgets.QPushButton(RGBControlWidget)
        self.yellowButton.setObjectName("yellowButton")
        self.gridLayout.addWidget(self.yellowButton, 2, 2, 1, 1)
        self.blackButton = QtWidgets.QPushButton(RGBControlWidget)
        self.blackButton.setObjectName("blackButton")
        self.gridLayout.addWidget(self.blackButton, 3, 1, 1, 1)
        self.verticalLayout.addLayout(self.gridLayout)
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.blueLabel = QtWidgets.QLabel(RGBControlWidget)
        self.blueLabel.setObjectName("blueLabel")
        self.gridLayout_2.addWidget(self.blueLabel, 2, 0, 1, 1)
        self.blueSlider = QtWidgets.QSlider(RGBControlWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.blueSlider.sizePolicy().hasHeightForWidth())
        self.blueSlider.setSizePolicy(sizePolicy)
        self.blueSlider.setMinimumSize(QtCore.QSize(128, 0))
        self.blueSlider.setMaximum(255)
        self.blueSlider.setOrientation(QtCore.Qt.Horizontal)
        self.blueSlider.setObjectName("blueSlider")
        self.gridLayout_2.addWidget(self.blueSlider, 2, 1, 1, 1)
        self.blueSpinBox = QtWidgets.QSpinBox(RGBControlWidget)
        self.blueSpinBox.setMaximum(255)
        self.blueSpinBox.setObjectName("blueSpinBox")
        self.gridLayout_2.addWidget(self.blueSpinBox, 2, 2, 1, 1)
        self.greenLabel = QtWidgets.QLabel(RGBControlWidget)
        self.greenLabel.setObjectName("greenLabel")
        self.gridLayout_2.addWidget(self.greenLabel, 1, 0, 1, 1)
        self.redSpinBox = QtWidgets.QSpinBox(RGBControlWidget)
        self.redSpinBox.setMaximum(255)
        self.redSpinBox.setObjectName("redSpinBox")
        self.gridLayout_2.addWidget(self.redSpinBox, 0, 2, 1, 1)
        self.redLabel = QtWidgets.QLabel(RGBControlWidget)
        self.redLabel.setObjectName("redLabel")
        self.gridLayout_2.addWidget(self.redLabel, 0, 0, 1, 1)
        self.redSlider = QtWidgets.QSlider(RGBControlWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.redSlider.sizePolicy().hasHeightForWidth())
        self.redSlider.setSizePolicy(sizePolicy)
        self.redSlider.setMinimumSize(QtCore.QSize(128, 0))
        self.redSlider.setMaximum(255)
        self.redSlider.setOrientation(QtCore.Qt.Horizontal)
        self.redSlider.setObjectName("redSlider")
        self.gridLayout_2.addWidget(self.redSlider, 0, 1, 1, 1)
        self.greenSpinBox = QtWidgets.QSpinBox(RGBControlWidget)
        self.greenSpinBox.setMaximum(255)
        self.greenSpinBox.setObjectName("greenSpinBox")
        self.gridLayout_2.addWidget(self.greenSpinBox, 1, 2, 1, 1)
        self.greenSlider = QtWidgets.QSlider(RGBControlWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.greenSlider.sizePolicy().hasHeightForWidth())
        self.greenSlider.setSizePolicy(sizePolicy)
        self.greenSlider.setMinimumSize(QtCore.QSize(128, 0))
        self.greenSlider.setMaximum(255)
        self.greenSlider.setOrientation(QtCore.Qt.Horizontal)
        self.greenSlider.setObjectName("greenSlider")
        self.gridLayout_2.addWidget(self.greenSlider, 1, 1, 1, 1)
        self.verticalLayout.addLayout(self.gridLayout_2)
        self.blueLabel.setBuddy(self.blueSlider)
        self.greenLabel.setBuddy(self.greenSlider)
        self.redLabel.setBuddy(self.redSlider)

        self.retranslateUi(RGBControlWidget)
        QtCore.QObject.connect(self.redSlider, QtCore.SIGNAL("valueChanged(int)"), self.redSpinBox.setValue)
        QtCore.QObject.connect(self.greenSlider, QtCore.SIGNAL("valueChanged(int)"), self.greenSpinBox.setValue)
        QtCore.QObject.connect(self.blueSlider, QtCore.SIGNAL("valueChanged(int)"), self.blueSpinBox.setValue)
        QtCore.QObject.connect(self.redSpinBox, QtCore.SIGNAL("valueChanged(int)"), self.redSlider.setValue)
        QtCore.QObject.connect(self.greenSpinBox, QtCore.SIGNAL("valueChanged(int)"), self.greenSlider.setValue)
        QtCore.QObject.connect(self.blueSpinBox, QtCore.SIGNAL("valueChanged(int)"), self.blueSlider.setValue)
        QtCore.QMetaObject.connectSlotsByName(RGBControlWidget)

    def retranslateUi(self, RGBControlWidget):
        RGBControlWidget.setWindowTitle(QtWidgets.QApplication.translate("RGBControlWidget", "RGB Control Widget", None, -1))
        self.whiteButton.setText(QtWidgets.QApplication.translate("RGBControlWidget", "White", None, -1))
        self.redButton.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Red", None, -1))
        self.greenButton.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Green", None, -1))
        self.blueButton.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Blue", None, -1))
        self.cyanButton.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Cyan", None, -1))
        self.magentaButton.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Magenta", None, -1))
        self.yellowButton.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Yellow", None, -1))
        self.blackButton.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Black", None, -1))
        self.blueLabel.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Blue", None, -1))
        self.greenLabel.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Green", None, -1))
        self.redLabel.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Red", None, -1))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'calibration_panel.ui',
# licensing of 'calibration_panel.ui' applies.
#
# Created: Fri Oct 25 09:11:18 2019
#      by: pyside2-uic  running on PySide2 5.13.1
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_CalibrationPanel(object):
    def setupUi(self, CalibrationPanel):
        CalibrationPanel.setObjectName("CalibrationPanel")
        CalibrationPanel.resize(95, 158)
        self.verticalLayout = QtWidgets.QVBoxLayout(CalibrationPanel)
        self.verticalLayout.setObjectName("verticalLayout")
        self.buttonBox = QtWidgets.QDialogButtonBox(CalibrationPanel)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Save)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(CalibrationPanel)
        QtCore.QMetaObject.connectSlotsByName(CalibrationPanel)

    def retranslateUi(self, CalibrationPanel):
        CalibrationPanel.setWindowTitle(QtWidgets.QApplication.translate("CalibrationPanel", "Calibration", None, -1))
        CalibrationPanel.setTitle(QtWidgets.QApplication.translate("CalibrationPanel", "Calibration", None, -1))

